#
# spec file for package konsole
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.6.0

%bcond_without released
Name:           konsole
Version:        24.05.1
Release:        1.1
Summary:        KDE Terminal
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/konsole
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
Source3:        Root_Shell.profile
Source4:        konsolesu.desktop
Source21:       utilities-terminal-su-16.png
Source22:       utilities-terminal-su-22.png
Source23:       utilities-terminal-su-32.png
Source24:       utilities-terminal-su-48.png
Source25:       utilities-terminal-su-64.png
Source26:       utilities-terminal-su-128.png
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6ConfigWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6NewStuff) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6NotifyConfig) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6Pty) >= %{kf6_version}
BuildRequires:  cmake(KF6Service) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(icu-i18n) >= 61.0
BuildRequires:  pkgconfig(icu-uc) >= 61.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
Requires:       konsole-part = %{version}
Obsoletes:      konsole5 < %{version}
Provides:       konsole5 = %{version}

%description
Konsole is a terminal emulator for the K Desktop Environment.

%package part
Summary:        KDE Terminal
Recommends:     konsole-part-lang
Obsoletes:      konsole5-part < %{version}

%description part
Konsole is a terminal emulator for the K Desktop Environment.
This package provides KPart of the Konsole application.

%package -n konsole-part-lang
Summary:        Translations for package konsole
Requires:       konsole-part = %{version}
Provides:       konsole-lang = %{version}
Obsoletes:      konsole-lang < %{version}
Provides:       konsole-part-lang-all = %{version}
BuildArch:      noarch

%description -n konsole-part-lang
Provides translations for the "konsole-part" package.

%package zsh-completion
Summary:        ZSH completion for konsole
Requires:       konsole = %{version}
Supplements:    (konsole and zsh)
BuildArch:      noarch

%description zsh-completion
ZSH command line completion support for konsole.

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-man --with-html --all-name

install -D -m 0644 %{SOURCE3}  "%{buildroot}%{_kf6_sharedir}/konsole/Root Shell.profile"
install -D -m 0644 %{SOURCE4}  %{buildroot}%{_kf6_applicationsdir}/
install -D -m 0644 %{SOURCE21} %{buildroot}%{_kf6_iconsdir}/hicolor/16x16/apps/utilities-terminal_su.png
install -D -m 0644 %{SOURCE22} %{buildroot}%{_kf6_iconsdir}/hicolor/22x22/apps/utilities-terminal_su.png
install -D -m 0644 %{SOURCE23} %{buildroot}%{_kf6_iconsdir}/hicolor/32x32/apps/utilities-terminal_su.png
install -D -m 0644 %{SOURCE24} %{buildroot}%{_kf6_iconsdir}/hicolor/48x48/apps/utilities-terminal_su.png
install -D -m 0644 %{SOURCE25} %{buildroot}%{_kf6_iconsdir}/hicolor/64x64/apps/utilities-terminal_su.png
install -D -m 0644 %{SOURCE26} %{buildroot}%{_kf6_iconsdir}/hicolor/128x128/apps/utilities-terminal_su.png

%fdupes -s %{buildroot}

%ldconfig_scriptlets
%ldconfig_scriptlets part

%files
%license LICENSES/*
%doc README.md
%doc %lang(en) %{_kf6_htmldir}/en/konsole/
%{_kf6_applicationsdir}/konsolesu.desktop
%{_kf6_applicationsdir}/org.kde.konsole.desktop
%{_kf6_appstreamdir}/org.kde.konsole.appdata.xml
%{_kf6_bindir}/konsole
%{_kf6_bindir}/konsoleprofile
%{_kf6_configdir}/konsolerc
%{_kf6_iconsdir}/hicolor/*/apps/utilities-terminal_su.png
%{_kf6_knsrcfilesdir}/konsole.knsrc
%dir %{_kf6_plugindir}/konsoleplugins
%{_kf6_plugindir}/konsoleplugins/konsole_quickcommandsplugin.so
%{_kf6_plugindir}/konsoleplugins/konsole_sshmanagerplugin.so
%{_kf6_libdir}/libkonsoleapp.so.*
%dir %{_kf6_sharedir}/kio
%dir %{_kf6_sharedir}/kio/servicemenus
%{_kf6_sharedir}/kio/servicemenus/konsolerun.desktop
%{_kf6_sharedir}/kglobalaccel/org.kde.konsole.desktop
%{_kf6_libdir}/kconf_update_bin/konsole_globalaccel
%{_kf6_libdir}/kconf_update_bin/konsole_show_menubar
%{_kf6_sharedir}/kconf_update/konsole.upd
%{_kf6_sharedir}/kconf_update/konsole_add_hamburgermenu_to_toolbar.sh

%files part
%{_kf6_debugdir}/konsole.categories
%{_kf6_libdir}/libkonsoleprivate.so.*
%{_kf6_notificationsdir}/konsole.notifyrc
%dir %{_kf6_plugindir}/kf6/parts
%{_kf6_plugindir}/kf6/parts/konsolepart.so
%{_kf6_sharedir}/konsole/

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_konsole

%files part-lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/konsole/

%changelog
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- Changes since 24.04.80:
  * use KIconTheme::initTheme & KStyleManager::initStyle to ensure proper styling outside of plasma
  * Remove unused includes
  * Construct tabbar with tabwidget parent
  * Fix case when Lam Alef is at the end of the line
  * Don't use Lam-Alef ligatures when shaping arabic letters (kde#478181)
  * Supress incorrect resize notifications
  * Fixed the window geometry config file placement.
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes since 24.02.2, only listing bugfixes:
  * Character: Return stringWidth, not value of ignoreWcWidth (kde#485155)
  * Fix hamburger menu/toolbar issues when splitting tabs (kde#474848)
  * Override width of YiJing Hexagram Symbols Unicode characters (0x4dc0-0x4dff) (kde#421625)
  * Add next/previous actions to change the profile of the current terminal (kde#413258)
  * Add hamburger menu action to all active views (kde#484171)
  * Check only IXON when getting flow control state (kde#457924)
  * Do not enclose CTL tab in appearance dialogue in its own qwidget (kde#474309)
  * Fix strings to allow translations (kde#482364)
  * Change type of tokenBuffer to QList allow longer length of tokens. (kde#479241)
  * Draw block cursor with antialiasing (kde#483197)
  * Draw block cursor outline with MiterJoin (kde#483197)
  * Fallback to home dir if initial working dir is inaccessible (kde#470262)
  * Reshow configuration dialog after toggling borders (kde#479081)
  * Fix getting FreeBSD process name (kde#480196)
  * Fix touchscreen scroll inconsistency (kde#450440)
  * Support non-BMP codepoints in HTMLDecoder (kde#479983)
  * terminalDisplay/TerminalFonts: fix checking if emojiFont is set (kde#481211)
  * fix: Issue with focus setting on wdg after relocating to a new splitter (kde#479858)
  * Implemented DBus methods for reading displayed text (kde#238032)
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- Changes since 24.02.1:
  * Add hamburger menu action to all active views (kde#484171)
  * Check only IXON when getting flow control state (kde#457924)
  * Draw block cursor with antialiasing (kde#483197)
  * Draw block cursor outline with MiterJoin (kde#483197)
  * Fallback to home dir if initial working dir is inaccessible (kde#470262)
  * Reshow configuration dialog after toggling borders (kde#479081)
  * Fix getting FreeBSD process name (kde#480196)
  * Avoid constructing QChar from non-BMP codepoints
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- Changes since 24.02.0:
  * Don't rely on qtpaths for kconf_update scripts
  * Fix Qt 6 assert on QChar outside BMP
  * Support non-BMP codepoints in HTMLDecoder (kde#479983)
  * terminalDisplay/TerminalFonts: fix checking if emojiFont is set (kde#481211)
  * fix: Issue with focus setting on wdg after relocating to a new splitter (kde#479858)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- Changes since 23.08.3:
  * Apply split view icons to the session context menu too.
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: initial import snapcraft files.
  * Fix signed integer overflow due to uninitialized vars warning
  * Account for CJK wide chars in copyLineToStream
  * Add test case for block selection of CJK chars
  * Don't select half a CJK character (kde#474055)
  * Don't require FreeBSD/Qt5 tests to pass
  * Don't try to free terminalPart.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Fix crashes in testTerminalInterface (kde#473043)
- Drop patch, merged upstream:
  * 0001-Fix-crashes-in-testTerminalInterface.patch
* Mon Sep  4 2023 Christophe Marin <christophe@krop.fr>
- Add upstream crash fix (kde#473043)
  * 0001-Fix-crashes-in-testTerminalInterface.patch
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * ScreenWindow::updateCurrentLine:  Better bound currentLine
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Fixed search bar false positive after clear scrollback (and reset) (kde#407317)
  * Hides redundant widgets on dialog for emoji font selection (kde#469563)
  * Eliminate compilation warnings for plugins from using QAction::setShortcut(s) (kde#462615)
  * Adjust selection point coords when scrollback shrinks (kde#470346)
  * Disable keyboard selection mode on resize (kde#467872)
  * Do not allow an invalid parent to be set in profiles (kde#467790)
  * Invalidate selection reference points on resize (kde#464040)
  * Draw selected background for right half of double width char if selected (kde#468465)
  * Fix crash in ProfileSettings (kde#423136)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Tab bar settings: fix MIME type filtering of custom CSS file picker
  * Hides redundant widgets on dialog for emoji font selection (kde#469563)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Adjust selection point coords when scrollback shrinks (kde#470346)
  * Add tests to check fix of invalid parent in profile
  * Do not allow an invalid parent to be set in profiles (kde#467790)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Invalidate selection reference points on resize (kde#464040)
  * Fix kglobalaccel integration
  * Draw selected background for right half of double width char if selected (kde#468465)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
- Drop patch, fixed upstream:
  * 0001-Fix-error-when-trying-to-edit-the-editable-parts-of-.patch
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix editing imported SSH hosts (kde#455290):
  * 0001-Fix-error-when-trying-to-edit-the-editable-parts-of-.patch
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * Add support for DECSTR (Soft Terminal Reset) (kde#134892)
  * Identify as VT2xx with DECCOLM and SIXEL (kde#450407)
  * More robust reflow on zsh with semantic prompts (kde#447830)
  * Switch focus when closing inactive tab with splits (kde#446830)
  * Fix visual bell (kde#445520)
  * Pass widget again to monitoring KNotifications (kde#443117)
  * Pass widget again to KNotification on bell (kde#443117)
  * Fix copying one single char (kde#448144)
  * Make %%w and %%# work for bell notifications (kde#435644)
  * Only enable maximize terminal button in split header bar when usable (kde#435029)
  * Use tighter matching when finding the default profile file name (kde#447872)
  * ViewSplitter will now consistently create even-spaced splits (kde#447074)
  * TerminalPainter: Pass nextPos to hasSameWidth (kde#446655)
  * Kate-like touchscreen scrolling support (kde#437553)
  * Handle changing cursor shape property without creating a new profile (kde#445590)
  * Disconnect view/session after drag-and-drop (kde#442238)
  * Improve performance of outputting text to screen (kde#443885)
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Update copyright year
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * Use tighter matching when finding the default profile file name (kde#447872)
  * SSHManager: Fix two i18n problems
  * Fix localization in ssh widget ui.
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Open bookmarks toolbar button on click; don't require press-and-hold (kde#446339)
  * Use new "edit-copy-path" icon for "Copy Location" menu item
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Fix changing non-Breeze scrollbar colors at runtime
  * Adapt scrollbar to terminal color scheme for Breeze widget style again
  * Revert "Let the scrollbar follow the app color scheme"
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Too many changes since 21.08.3, only listing bugfixes:
  * EditProfileDialog: fix build with Clang and libc++ (kde#443420)
  * Make "Find Next/Previous" icons in Edit menu consistent with those in the search bar (kde#443244)
  * Use one option to control menubar visibility (kde#440328)
  * Always save the window state and geometry (kde#442252)
  * Move splitview toolbar buttons into a button menu (kde#437555)
  * Update copyright year to 2021 (kde#442016)
  * Fix missing new-tab menu when only one profile exists (kde#436264)
  * Hide the Plugins menu if no plugins were loaded (kde#441199)
  * Fix the maximum port number in the SSH Manager plugin (kde#441889)
  * For the fallback profile change the menu text to "Create New Profile" (kde#440885)
  * Don't resize window when switching virtual desktops in OpenBox (kde#441610)
  * Only emit empty() in SessionFinished() when in TabbedNavigation mode (kde#441206)
  * improve session closing behavior (kde#401898)
  * Prevent window "flashing" when closing the last session (kde#432077)
  * Fix crash when closing a tab using the close button (kde#411962)
  * Fix KXmlGUI toolbars; and Konsole MainWindow size (kde#430036)
  * Fix crash when setting blur effect (kde#439871)
  * Don't create a new temp profile when --workdir is used to launch Konsole (kde#435537)
  * Resize lines when clearing to end of line. (kde#432669)
  * Fix one crash in the sshmanager plugin (kde#439551)
- Drop upstream patch:
  * 0002-Always-save-the-window-state-and-geometry.patch
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Update copyright year to 2021 (kde#442016)
  * improve session closing behavior (kde#401898)
  * Hide the Plugins menu if no plugins were loaded (kde#441199)
  * Fix the maximum port number in the SSH Manager plugin (kde#441889)
  * The default navigation method should be TabbedNavigation
  * Don't resize window when switching virtual desktops in OpenBox (kde#441610)
- Drop upstream patch:
  * 0001-Don-t-resize-window-when-switching-virtual-desktops-.patch
* Sat Sep 18 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to fix some more window size related issues:
  * 0001-Don-t-resize-window-when-switching-virtual-desktops-.patch
    (kde#441610)
  * 0002-Always-save-the-window-state-and-geometry.patch
    (kde#442252, boo#1189927)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- Changes since 21.08.0:
  * Only emit empty() in SessionFinished() when in TabbedNavigation mode (kde#441206)
  * When closing a session, don't close the whole window if there are splits
  * Fix MainWindow size when there is no saved size
  * Fix KXmlGUI toolbars; and Konsole MainWindow size (kde#430036)
  * Fix crash when setting blur effect (kde#439871)
  * Prevent window "flashing" when closing the last session (kde#432077)
- Drop upstream patches:
  * 0001-Fix-KXmlGUI-toolbars-and-konsole-MainWindow-size.patch
  * 0001-Fix-MainWindow-size-when-there-is-no-saved-size.patch
* Wed Aug 18 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch from upstream to fix KXmlGUI toolbars and Konsole
  MainWindow size (kde#436471, kde#430036, kde#439339, boo#1188074):
  * 0001-Fix-KXmlGUI-toolbars-and-konsole-MainWindow-size.patch
- Add patch from upstream to fix the MainWindow size when there is
  no saved size (like the first time a user runs Konsole)
  (kde#437791):
  * 0001-Fix-MainWindow-size-when-there-is-no-saved-size.patch
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Resize lines when clearing to end of line. (kde#432669)
  * Fix one crash in the sshmanager plugin (kde#439551)
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * Fix memory link in ssh manager QRegularExpressionValidator() (kde#439555)
  * Fix assert _currentTerminalDisplay in Screen::setTextSelectionRendition (kde#439529)
  * Prevent 1px sizehint when there is no preconfiguration (kde#437791)
  * Fix crash/warn on history reflow (kde#436916)
  * Add option to always invert text selection colours (kde#435309)
  * Only generate autoscroll events while selecting (kde#391975)
  * Support DECSET 1003 mouse move tracking (kde#391967)
  * Don't send move events for normal mouse tracking (kde#302731)
  * Do not swallow right button presses on double-click (kde#425926)
  * Fix correct beginning position while copying texts (kde#436845)
  * Fix crash on resize while doing other things (kde#436327)
- Drop upstream patch:
  * 0001-Prevent-1px-sizehint-when-there-is-no-preconfigurati.patch
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Wed Jun 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix initial size after kxmlgui changes (kde#437791):
  * 0001-Prevent-1px-sizehint-when-there-is-no-preconfigurati.patch
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Allow /bin/sh as a profile command (kde#436242)
  * Fix alpha channel of scrollbar colors (kde#437223)
  * Don't override profile icon in "New Tab" menu (kde#437200)
  * Fix crash when using a color scheme with random colors (kde#434892)
  * Fix type of randomSeed parameter
- Drop upstream patch:
  * 0001-Fix-alpha-channel-of-scrollbar-colors.patch
* Tue May 25 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix scrollbar appearance in some configurations (kde#437223):
  * 0001-Fix-alpha-channel-of-scrollbar-colors.patch
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * Fix Screen::_cuY position inside screen
  * Fix crash showing Settings Dialog (kde#436366)
  * Add missing include to fix build on gcc-11
  * Make CompactHistoryBlock size variable (v21.04.0) (kde#436031)
  * Use inverted colours when calculated fancy BG has too low contrast (kde#435309)
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Changes since 21.03.80:
  * Always sort the profiles by name in 'File -> New Tab'
  * Fix crash in ProfileSettings; clone selected profile settings to new profile
  * Unmaximize terminal before moving to new tab
  * ProfileSettings: use generateUniqueName() when creating new profiles
  * ProfileManager: remove some fallback-profile-related code
  * Don't edit the Fallback profile, instead create a new one
  * Clean up some more "favourite profile"-related code
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Changes since 20.12.2:
  * Delete client builder before d-pointer of KXMLGUIClient is killed (kde#432421)
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * Fix the handbook URL in the maintainer README
  * Fix crash exiting all tabs at the same time (kde#431827)
  * Fix "Remember window size" not working when unchecked (kde#427610)
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Correct columns size with highlightScrolledLines (kde#429600)
  * Only link konsoleprofile to konsoleprivate (kde#430492)
  * Revert 'Fix bold character color paint'
- Dropped patches, now upstream:
  * Only-link-konsoleprofile-to-konsoleprivate.patch
* Wed Dec 30 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add Only-link-konsoleprofile-to-konsoleprivate.patch to fix
  choosing a profile in the "New Tab" button's menu (boo#1180311,
  kde#424986), and possible crashes on exit (kde#430492)
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * Fix bold character color paint (kde#405345)
  * Require cmake 3.13
  * SessionController: don't delete actions removed from QMenu manually
  * Revert "Uses SessionDisplayConnection to connect sessions and displays."
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- Changes since 20.11.80:
  * SessionController: iterate over a const container
  * SessionContoller: fix crash when closing session from Konsole KPart (kde#429538)
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes to list here.
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Fix Maximize current Terminal (Keyboard vs Mouse) (kde#418498)
  * Fix URL hint numbering
  * Fix 'Alt+C' closing split view (kde#424654)
  * For "Manage Profiles" always open the "Profiles" page in settings (kde#428206)
  * Fix duplicates link-related entries in context menu (kde#426808)
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Changes since 20.08.1:
  * Fix crash when extending selection after switching between primary and secondary screen (kde#398320)
  * Set a minimum thumbnail size (kde#425544)
  * Fix vertical scrolling with touchpads and trackpoints. (kde#425765)
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Add OARS
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- Changes since 20.07.90:
  * Fix underlining files with non-ascii names (kde#424404)
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- Changes since 20.07.80:
  * Unminimize Konsole when --new-tab is called
  * Fix focus when using --new-tab (kde#421408)
  * Adjust context markers
  * Add some context markers
  * kcfg use Bool, not bool
  * Revert "Update kcfg URLS to https"
  * Polish the highlightScrolledLines feature
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes to list here.
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Make the search bar usable after showing KMessageWidget
  * Don't add extra newlines when pasting from GTK applications (kde#421480)
  * Fix shortcuts for Yakuake grow-terminal actions (kde#415164)
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- Changes since 20.04.1:
  * Fix lambda capture 'this' is not used
  * Notify current cursor position might be changed to input methods (kde#420799)
  * Fix SearchTask memleak
  * Fix override switch-to-tab action in Yakuake (kde#420503)
  * [SessionController] Fix crash caused by text encoding menu (kde#419526)
  * Fix konsolepart segfault when closing after showing context menu (kde#415762)
  * Fix crash when closing session in KonsolePart via menu (kde#420817)
- Drop upstream patches:
  * Fix-crash-when-closing-session-in-KonsolePart-via-menu.patch
  * Fix-konsolepart-segfault-when-closing-after-showing-context-menu.patch
* Fri May 29 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to fix possible crash when closing a session
  in KonsolePart (boo#1169408, kde#420817, kde#420695, kde#415762):
  * Fix-crash-when-closing-session-in-KonsolePart-via-menu.patch
  * Fix-konsolepart-segfault-when-closing-after-showing-context-menu.patch
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Use Qurl::fromPercentEncoding for bookmarks (kde#420791)
  * [TerminalDisplay] Change the mouse cursor shape back to beam on leaveEvent
  * Do not show "Search for" if web shortcuts are disabled (kde#417048)
  * Remove unneeded <optional> include
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Add ViewSplitter::showEvent() (kde#411543)
  * [BookmarkMenu] Adapt the code to KBookmarks 5.69 changes (kde#419981)
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Remove shortcut for detach tab
  * Add missing includes
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Implements default keyboard shortcuts for tab navigation (alt+n) (kde#416362)
  * Fix token buffer indexing (kde#415249)
  * Revert supportTabs() removal to fix bookmenu issue (kde#415549)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update copyright year
  * ColorScheme: fix stack-use-after-scope detected by ASAN
  * Update Appstream for new release
  * Copy _colorRandomization when copying a new ColorScheme
  * Fix token buffer indexing (kde#415249)
  * Revert removal to allow Bookmark tabs as Folders to work
  * Revert supportTabs() removal to fix bookmenu issue (kde#415549)
- Drop Add ColorScheme-fix-stack-use-after-scope.patch. Merged upstream.
- Drop the obsolete fix-build-with-gcc48.patch patch
* Tue Dec 17 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add ColorScheme-fix-stack-use-after-scope.patch to fix wrong
  background color with "Black on Random Light" color scheme
  (boo#1159247, kde#415242)
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes to list here, only listing bugfixes:
  * Fix tabs not indicating activity (kde#406828)
  * Fix OSC sequence parsing (kde#231405)
  * Add missing setFocusProxy() call in ViewManager (kde#411181)
  * Start new splits in same directory as current session (kde#411332)
  * Fix search bar placement (kde#405482)
  * Add a "Do not ask again" option to close session dialog (kde#405481)
  * Remove env variable KONSOLE_PROFILE_NAME (kde#406955)
  * Do not allow adding duplicates in bookmarks (kde#408939)
- Dropped patches, now upstream:
  * Fix-tabs-not-indicating-activity.patch
* Fri Nov 15 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add Fix-tabs-not-indicating-activity.patch to fix indicating
  activity in background tabs (kde#406828)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Fix scrollbar position (kde#412348)
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Allow loading of pre 19.08 session files (kde#412173)
  * Keep empty lines when "trim leading spaces" is enabled (kde#412479)
  * enable hidpi auto scaling
  * anti-alias line character painting, too, with the text aliasing config options
  * fix many of the rendering artifacts for hi-dpi setups
  * Correct split view and keyboard navigation (kde#411387)
  * Fix split view crashes when using keyboard navigation with some themes (kde#411387)
  * Make sure font weight value is within allowed range
  * fix rendering artifacts introduced by calling winId (kde#411965)
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Fix the fallback code used when restoring session fails
  * Add scrollbuttons for tabs when tabbar is full
  * Restore "Show 'new tab' button" option in Konsole Settings
  * Port to non-deprecated KWindowSystem::unminimizeWindow
  * Fix crash on "Close Current Tab" handling (kde#410607)
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Fix focus getting stuck in menu when XDG_CURRENT_DESKTOP ≠ kde (kde#410641)
  * Do not allow 'Close Current Tab" to crash
  * Fix dbus newSession() three methods to work
  * Remove accelerators from tabs when pressing ALT (kde#410488)
- Drop Fix-dbus-newSession-three-methods-to-work.patch. Merged upstream.
* Fri Aug  9 2019 wbauer@tmo.at
- Add Fix-dbus-newSession-three-methods-to-work.patch to fix the
  newSession() D-BUS method (boo#1143335, kde#410469)
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Mark constructor explicit
  * Add/fix KUIT context marker
  * Add KUIT context marker
  * Fix initial terminal size
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Variables for column/row are switched for Profile-Initial Terminal Size
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Manual: Fix shortcut for View → Split View → Close Active
  * std::stable_sort requires !(a < a)
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Fixes minor memory leaks
  * Use QTEST_GUILESS_MAIN
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * Fix-bold-font.patch
  * Add-special-support-for-block-characters.patch
  * Extend-character-clipping-by-grouping-it-with-spaces.patch
  * Improve-built-in-line_block-characters-drawing.patch
  * Fix-ibeam-and-underline-cursor-rendering.patch
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Wed Mar  6 2019 wbauer@tmo.at
- Add upstream patches to improve and/or fix rendering of
  line/block chars, cursors, and characters with wide glyphs:
  * Add-special-support-for-block-characters.patch
  * Extend-character-clipping-by-grouping-it-with-spaces.patch
    (kde#401298)
  * Improve-built-in-line_block-characters-drawing.patch
    (kde#402415)
  * Fix-ibeam-and-underline-cursor-rendering.patch (kde#402589)
- Drop patches to disable antialiasing as the rendering problems
  are fixed by above patches:
  * 0001-Revert-fix-drawing-box-chars-avoid-storing-and-savin.patch
  * 0002-Revert-Antialias-line-drawing-characters.patch
* Mon Mar  4 2019 wbauer@tmo.at
- Add Fix-bold-font.patch to fix problems with rendering text in
  bold (boo#1095022)
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Revert "Fix crash in extendSelection" (kde#403117)
* Mon Jan 21 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Disable antialiasing to fix appearance of bold lines (kde#401463):
  * 0001-Revert-fix-drawing-box-chars-avoid-storing-and-savin.patch
  * 0002-Revert-Antialias-line-drawing-characters.patch
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * Fix crash in extendSelection (kde#402452)
  * Fix regression on tab color not reverting back to 'no activity' color (kde#402541)
  * Don't change alternate scrolling state after calling reset() (kde#402461)
  * Fix crash while trying to move tab with only one view (kde#402278)
  * fix cursor when anti aliasing is enabled
  * Fix crash when changing from blinking cursor to block cursor
  * fix drawing box chars, avoid storing and saving state all the time (kde#401463)
  * Restore default tabbar style when custom stylesheet is disabled
  * Fix condition to redraw search result line
- Dropped patches, now upstream:
  * Fix-regression-on-tab-color-not-reverting-back-to-no-activity-color.patch
  * fix-drawing-box-chars.patch
  * fix-cursor-when-anti-aliasing-is-enabled.patch
* Sat Jan  5 2019 wbauer@tmo.at
- Add upstream patch to fix a regression that the tab-color did not
  revert back to the default color after an activity was signalled:
  * Fix-regression-on-tab-color-not-reverting-back-to-no-activity-color.patch
    (kde#402541)
* Fri Dec 21 2018 wbauer@tmo.at
- Add fix-cursor-when-anti-aliasing-is-enabled.patch to fix text
  cursor rendering regressions with anti-aliasing
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Fri Dec  7 2018 wbauer@tmo.at
- Add fix-drawing-box-chars.patch to fix bad border rendering, in
  mc for example (boo#1117446, kde#401463)
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * Fix ASAN issue for determining if running in a KPart
  * Allow small colour changes when varying dark backgrounds (kde#311263)
  * set variable in initialize list and explictly use bool in if
  * Fix search result highlight when scrolling
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
- Refreshed patches:
  * fix-build-with-gcc48.patch
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Scope the glib hack to only < Qt5.11.2 versions
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Don't pollute the environment inside Konsole with QT_NO_GLIB
  * Vt102EmulationTest: Use QTEST_GUILESS_MAIN
  * Revert "Change internal character type size to 32 bit"
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
- Refreshed patches:
  * fix-build-with-gcc48.patch
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Only consider startDragDistance for drag-n-drop tabs
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Backspace without CTRL should send '^?' (kde#394276)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Fix build with Qt 5.11_beta3 (dropping qt5_use_modules)
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Always preserve line breaks on "Select All" action (kde#352616)
  * Remove ESC sequences from pastes in bracketed mode
  * Make the keypad "5" key send "\E[E" when NumLock is off (kde#189116)
  * Convert & to &amp; for HTML decoder
  * Do not resize new screen lines (kde#392419)
* Tue Apr 10 2018 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to make it build with gcc 4.8 on
  Leap 42.3
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * konsole-D10064.id25855.diff
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Feb  1 2018 werner@suse.de
- Temporary add patch konsole-D10064.id25855.diff which is based on
  the Diff 25855 from https://phabricator.kde.org/D10064 for Support
  of ECMA-48 REP (boo#1054448, bsc#1078565, and kde#384620)
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * appdata: update doc URL, more https
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * fix spelling issue/reformat comment
  * Fix 2 issues with Profile->Edit Environment dialog
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Ignore xterm-DCS messages
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Ignore xterm-DCS messages
  * Remove delay in dragging tabs (kde#371939)
  * Validate scrollback destination folder for unlimited scrollback option
  * For KParts, read Scrollback File Location from konsolerc (kde#369496)
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
- Drop 0001-Fix-Manage-Profiles-option-from-KonsolePart.patch and
  0001-Make-KonsolePart-s-Manage-Profiles-dialog-name-uniqu.patch
  (merged upstream)
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jul 12 2017 fabian@ritter-vogt.de
- Replace %%lang_package with evaluated macro to be able to add proper
  Provides/Obsoletes to avoid file conflicts during installation
* Sat Jul  8 2017 wbauer@tmo.at
- Rename -lang package to konsole-part-lang and recommend it by the
  konsole-part package, the translations are used by the kpart too
  (boo#1027925)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Add a patch to fix an issue with the manage profiles option:
  * 0001-Make-KonsolePart-s-Manage-Profiles-dialog-name-uniqu.patch
* Sat Jun  3 2017 fabian@ritter-vogt.de
- Add patch to bring back the manage profiles option, needed by
  yakuake (kde#360072):
  * 0001-Fix-Manage-Profiles-option-from-KonsolePart.patch
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Add check for valid container (possible crash fix)
  * Correct ANSI string terminator (kde#231405)
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
- Remove patches, now upstream:
  * Pre-process-e-custom-command-argument.patch
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Fri Jan 27 2017 wbauer@tmo.at
- Add Pre-process-e-custom-command-argument.patch to restore proper
  handling of the -e command line option (boo#1018087, kde#366793)
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Dropped patches:
  + fix-reparsing-of-command-line-arguments.patch
  + only-use-foreground-process-info-if-valid.patch
* Sun Nov 20 2016 wbauer@tmo.at
- Add only-use-foreground-process-info-if-valid.patch, should fix
  "random" crashes (kde#372401, kde#372620, kde#372619, kde#372593)
* Fri Nov 18 2016 wbauer@tmo.at
- Add fix-reparsing-of-command-line-arguments.patch to make konsole
  properly parse the command line options on start when an instance
  is already running, and not just reuse them from the already
  running instance (boo#1010890, kde#371863)
* Thu Nov 10 2016 wbauer@tmo.at
- Update build requirements
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Wed Oct 12 2016 lbeltrame@kde.org
- Drop Fix-updating-of-tab-title.patch, merged upstream
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep 23 2016 wbauer@tmo.at
- Add Fix-updating-of-tab-title.patch to update the tab title to
  the current program running again (boo#1000641, kde#368785)
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
- Drop upstreamed patches fix-transparency.patch and
  fix-extra-window-when-restored-by-session-management.patch
* Tue Aug 30 2016 wbauer@tmo.at
- Add fix-transparency.patch to fix transparent backgrounds
  (kde#366368)
* Sun Aug 28 2016 wbauer@tmo.at
- Add fix-extra-window-when-restored-by-session-management.patch to
  prevent creating an extra window upon session restoration
  (kde#367447)
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
- Drop upstreamed patch Write-profile-changes-to-Konsoles-location.patch
* Mon Jul 11 2016 wbauer@tmo.at
- Add Write-profile-changes-to-Konsoles-location.patch: fix
  modifying profiles when konsole is embedded in other applications
  (kde#364336)
* Fri Jul  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
- Drop upstreamed patches:
  * allow-certain-variable-width-fonts.patch
  * fix-profile-terminal-size.patch
* Wed Feb  3 2016 ftake@geeko.jp
- Add allow-certain-variable-width-fonts.patch: resolve no characters
  are shown on Chinese and Japanese environment (boo#962239)
  * For some monospaced fonts with ligatures or the ambiguous-width
    problem, QFontInfo::fixedPitch does not return true. When such
    font is selected for "Monospace", Konsole did not print anything.
* Mon Feb  1 2016 wbauer@tmo.at
- Add fix-profile-terminal-size.patch: allow profile's terminal
  size to work again (boo#964165, kde#345403)
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Mon Oct  5 2015 wbauer@tmo.at
- Own directory %%_kf5_sharedir/appdata to fix build on Leap
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Tue May 19 2015 wbauer@tmo.at
- Add Root Shell.profile (boo#908029)
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Dec  7 2014 tittiatcoke@gmail.com
- Split out the konsole binary and related files for coinstallability
  with the Frameworks based version
* Wed Dec  3 2014 tittiatcoke@gmail.com
  Update to KDE Applications 14.11.97
  * KDE Applications 14.12 Release Candidate
  * See http://www.kde.org/announcements/announce-applications-14.12-rc.php
  * Konsole is now KDE Frameworks based
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Wed Sep  5 2012 dmueller@suse.com
- update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Mon Jul 30 2012 dmueller@suse.com
- update to 4.8.5
  * see http://kde.org/announcements/changelogs/changelog4_8_4to4_8_5.php for details
* Fri Jun  1 2012 dmueller@suse.com
- update to 4.8.4
  * see http://kde.org/announcements/changelogs/changelog4_8_3to4_8_4.php for details
* Sun Apr 29 2012 dmueller@suse.com
- update to 4.8.3
  * see http://kde.org/announcements/changelogs/changelog4_8_2to4_8_3.php for details
* Sat Mar 31 2012 wstephenson@suse.com
- Add xz to BuildRequires
* Thu Mar 29 2012 dmueller@suse.de
- update to 4.8.2
  * see http://kde.org/announcements/changelogs/changelog4_8_1to4_8_2.php for details
* Fri Mar  2 2012 dmueller@suse.de
- update to 4.8.1
  * see http://kde.org/announcements/changelogs/changelog4_8_0to4_8_1.php for details
* Wed Jan 18 2012 dmueller@suse.de
- update to 4.8.0
  * first stable release of KDE 4.8 (only critical fixes over 4.7.98)
  * see http://kde.org/announcements/4.8/ for details
* Tue Jan 10 2012 dmueller@suse.de
- update to 4.7.98
  * RC2+ milestone release of KDE 4.8
  * see http://kde.org/announcements/4.8/ for details
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 dmueller@suse.de
- update to 4.7.4
  * see http://kde.org/announcements/changelogs/changelog4_7_3to4_7_4.php for details
* Wed Nov  2 2011 dmueller@suse.de
- update to 4.7.3
  * see http://kde.org/announcements/changelogs/changelog4_7_2to4_7_3.php for details
* Sun Oct  2 2011 dmueller@suse.de
- update to 4.7.2
  * see http://kde.org/announcements/changelogs/changelog4_7_1to4_7_2.php for details
* Sun Sep  4 2011 ctrippe@opensuse.org
- Set the name of the Root Shell profile in quotation marks
  (bnc#715857)
* Thu Sep  1 2011 dmueller@suse.de
- update to 4.7.1
  * Bugfixes over KDE 4.7.0
  * see http://kde.org/announcements/changelogs/changelog4_7_0to4_7_1.php for details
* Thu Aug 25 2011 idonmez@novell.com
- Add konsole-4.7-branch.patch: sync with 4.7 branch
  * Fix argument list growing over time.
  * Restore codec to profile setting or previous codec upon reset.
  * Only enable the tab popup menu 'Detach Tab' for > 1 tabs.
  * Fix $COLUMNS/$LINES after resizing.
  * When loading profile, do not initially set default profile
    as parent.
* Fri Jul 22 2011 dmueller@suse.de
- update to 4.7.0
  * Small fixes over KDE 4.7 RC2
  * see http://kde.org/announcements/4.7 for details
* Sat Jul  9 2011 dmueller@suse.de
- update to 4.6.95
* Tue Jun 28 2011 dmueller@suse.de
- update to 4.6.90
* Fri May 20 2011 dmueller@suse.de
- update to 4.6.80
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Creation of new package konsole as split-off from kdebase in GIT
* Wed Jan  5 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
- Removed patches:
  * dolphin-search-toolbar-bnc537372.diff (fixed upstream)
  * kdebase-4.5.3-konsole-crash.patch (upstream)
* Tue Nov 16 2010 cristian.rodriguez@opensuse.org
- Remove workaround for bko#246652, real fix is now in kdelibs
  revision 1197480.
* Sat Nov 13 2010 cristian.rodriguez@opensuse.org
-  Closing the shell via CTRL+D crashes [bko#246652]
* Fri Nov 12 2010 ctrippe@gmx.net
- Change the name of the konsole profile in konsolesu.desktop
  to fix the renamed profile
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Sun Aug 22 2010 ctrippe@gmx.net
- Change installation directory of konsole - Super User Icon (bnc#633082)
* Wed Aug  4 2010 wstephenson@novell.com
- Add patch to make Folder View on the default configuration
  show the desktop folder
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Mon May 31 2010 llunak@novell.com
- icon for root's Konsole (bnc#579828)
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Wed Feb 10 2010 llunak@novell.com
- add kwebkitpart-devel buildrequires
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Oct 15 2009 llunak@novell.com
- fix xdg-user-dir patch (bnc#543775)
* Fri Oct  9 2009 llunak@novell.com
- fix dolphin crash (kde#202176)
* Thu Oct  8 2009 llunak@novell.com
- use xdg-user-dir locations (bnc#540574)
* Thu Oct  8 2009 llunak@novell.com
- do not miss some translations from .desktop files (bnc#442800)
* Wed Oct  7 2009 llunak@novell.com
- dolphin search toolbar with current setup only shows an error
  message, disable it by default (bnc#537372)
* Tue Oct  6 2009 llunak@novell.com
- make disabling initial ksycoca check work (bnc#536545)
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff:
  * updated translations
  * dolphin: Update controller's url upon redirection (kde#186947)
  * few kdialog fixes
* Wed Sep  9 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff:
  * Konqueror: hide old history module from sidebar (kde#205521)
  * Dolphin: fix progress and capacity bar layout problems
  * Dolphin: fix selection in details view problems (kde#201459)
  * Konsolepart: show correct context menu (kde#186745)
  * Konsole: fix crash during search (kde#205495)
  * improved translations
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Tue Aug 18 2009 beineri@opensuse.org
- moved Root_Shell.profile to -workspace-branding-openSUSE package
* Sat Aug 15 2009 beineri@opensuse.org
- branch diff update: several dolphin fixes
- improve kinfocenter menu category
* Fri Aug 14 2009 beineri@opensuse.org
- add support to recreate default panel also in folder view mode
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Sat Jul 25 2009 beineri@opensuse.org
- add examples to kdialog documentation (bnc#439901)
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Mon Mar 16 2009 coolo@suse.de
- update 4_2_BRANCH.diff
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Wed Feb 18 2009 dmueller@suse.de
- update branch diff
* Fri Feb  6 2009 stbinner@suse.de
- update branch diff: Dolphin and Konqueror bug fixes
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Sat Jan  3 2009 stbinner@suse.de
- fix "Dolphin Super User Mode" start menu entry (bnc#449056)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Thu Nov 27 2008 ro@suse.de
- update baselibs.conf
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Thu Nov  6 2008 stbinner@suse.de
- show "Go Up" in Dolphin main tool bar
- fix grid option crash in Folder view plasmoid (bnc#441660)
* Tue Nov  4 2008 stbinner@suse.de
- Folder View plasmoid:
  * remove wrong error dialog when renaming (bnc#432728)
  * make settings dialogs available in containment context menu
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Sun Oct 26 2008 stbinner@suse.de
- two Konsole backports to close feature gap compared to KDE 3.5:
  * session management (kde#152761#c75)
  * keyboard shortcuts for accessing tabs (kde#156636)
- update folder view plasmoid, fixes bnc#434169)
* Thu Oct 23 2008 stbinner@suse.de
- only recommend nspluginwrapper on req of SLES proj mgt
* Wed Oct 22 2008 stbinner@suse.de
- lower preferences for opening folder as root (bnc#437850)
* Tue Oct 21 2008 stbinner@suse.de
- add menu entries for root konsole and root dolphin (bnc#433649)
- branch diff update: fixes kde#170470, kde#171729, kde#162022,
  kde#170048, kde#172014, kde#167667, kde#171861 and kde#170470
* Mon Oct 13 2008 stbinner@suse.de
- remove "Conflicts: yast2-theme-NLD"
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Wed Sep 24 2008 stbinner@suse.de
- add plasma.diff for folderview plasmoid backport
* Mon Sep 15 2008 dmueller@suse.de
- adjust buildrequires
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Sun Aug 24 2008 stbinner@suse.de
- build Konqueror kttsd plugin without webkitpart dependency
* Sat Aug 16 2008 stbinner@suse.de
- branch diff update
* Thu Jul 31 2008 dmueller@suse.de
- branch diff update
* Wed Jul 30 2008 coolo@suse.de
- fix file list to build
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Tue Jul  8 2008 dmueller@suse.de
- recommend dolphinpart for konqueror, otherwise its
  file management capabilities are limited
* Mon Jul  7 2008 dmueller@suse.de
- rename libkonq4 to libkonq5
- rename libkonq4-devel to libkonq-devel
* Fri Jul  4 2008 dmueller@suse.de
- update to 4.0.85
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Mon Jun  2 2008 dmueller@suse.de
- fix crash on mimetype determination (bnc#392255)
* Mon May 26 2008 dmueller@suse.de
- don't package Shell.profile (bnc#392954)
* Fri May 23 2008 stbinner@suse.de
- make konsole create utmp entries again (bnc#389715)
* Wed May  7 2008 coolo@suse.de
- fix file list of kde4-konqueror
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 dmueller@suse.de
- fix konsole assertion failure on tab close (bnc#371899)
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Tue Mar 11 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Thu Feb 21 2008 coolo@suse.de
- no longer build nsplugin64 - rely on nspluginwrapper
* Mon Feb 18 2008 dmueller@suse.de
- fix nspluginscan hang (#362522)
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Wed Feb  6 2008 stbinner@suse.de
- don't mark kwrite.desktop as unimportant
* Mon Feb  4 2008 stbinner@suse.de
- add 4_0_BRANCH.diff (install kinfocenter handbook from here)
* Mon Feb  4 2008 dmueller@suse.de
- update to the final tarball
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 27 2008 stbinner@suse.de
- update 4_0_BRANCH.diff (fix the nasty regression that resulted in
  konq opened from panel eating CPU, being barely responsive, and
  basically unable to load anything (such as the about page)
* Wed Jan 23 2008 stbinner@suse.de
- update 4_0_BRANCH.diff
* Sun Jan 20 2008 stbinner@suse.de
- update 4_0_BRANCH.diff
* Sat Jan  5 2008 dmueller@suse.de
- update to 4.0
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Fri Nov  2 2007 dmueller@suse.de
- filelist updates
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Thu Oct 18 2007 dmueller@suse.de
- update to 3.94.1
* Wed Oct 17 2007 ro@suse.de
- fix build: add directory to filelist
* Mon Oct  8 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720100
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717244
* Fri Sep 21 2007 stbinner@suse.de
- don't remove icons anymore after build check got fixed (#307017)
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712052
* Mon Sep 10 2007 dmueller@suse.de
- don't set $LANGUAGE in konsole (#305210)
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703920
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700775
* Wed Aug 15 2007 stbinner@suse.de
- fix more file conflicts
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697325
- fix file conflicts
* Sat Jul 28 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 19 2007 stbinner@suse.de
- don't show System Settings on non-KDE/KDE3 desktop
* Mon Jul 16 2007 stbinner@suse.de
- use the non generic lib version for libkonq
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn672298
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679137
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Mon Jun  4 2007 stbinner@suse.de
- fix build
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Wed May 23 2007 stbinner@suse.de
- run %%fdupes
- fix prefix of two bins
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Tue May 15 2007 stbinner@suse.de
- show .desktop files of kdebase4-runtime only in a KDE session
* Sat May 12 2007 stbinner@suse.de
- libkdeinit -> libkdeinit4
* Thu May 10 2007 stbinner@suse.de
- fix package file conflicts
* Mon May  7 2007 stbinner@suse.de
- initial package in abuild
